@@ -23,11 +23,11 @@ mkdir 'tmp', 0700 unless -d 'tmp';
 mkdir 'tmp/Text', 0700 unless -d 'tmp/Text';
 copy('Starfish.pm','tmp/Text/Starfish.pm');
 
-{
-    my $f = getfile('starfish');
-    $f =~ s<^#!/usr/bin/perl>{#!/usr/bin/perl -I../blib/lib} or die;
-    putfile('tmp/starfish', $f);
-}
+#{
+#    my $f = getfile('starfish');
+#    $f =~ s<^#!/usr/bin/perl>{#!/usr/bin/perl -I../blib/lib} or die;
+#    putfile('tmp/starfish', $f);
+#}
 
 chdir 'tmp' or die;
 &testcase('01', 'replace');
@@ -37,13 +37,6 @@ chdir 'tmp' or die;
 &testcase('06'); # was 5
 &testcase('07'); # was 25, Makefile
 &testcase('08'); # Makefile
-
-#    # 25
-#    copy('../testfiles/25_Makefile','Makefile');
-#    `perl -I. -- starfish Makefile`;
-#    okfiles('../testfiles/25_Makefile.out', 'Makefile');
-
-
 &testcase(2);
 &testcase(3);
 &testcase(4);
@@ -53,12 +46,14 @@ chdir 'tmp' or die;
 &testcase(9, 'out');
 # 10
     copy('../testfiles/9_java.out', '9_java.out');
-    `perl -I. -- starfish -o=10_java.out -e="$slash_hack\$Starfish::HideMacros=1" 9_java.out`;
+    #`perl -I. -- starfish -o=10_java.out -e="$slash_hack\$Starfish::HideMacros=1" 9_java.out`;
+    starfish_cmd(qw(-o=10_java.out -e=$Starfish::HideMacros=1 9_java.out));
     ok(getfile('10_java.out'),
 	   getfile("../testfiles/10_java.out"));
     # 11
     copy('../testfiles/10_java.out', '10.java');
-    `perl -I. -- starfish -o=11_java.out 10.java`;
+    #`perl -I. -- starfish -o=11_java.out 10.java`;
+    starfish_cmd(qw(-o=11_java.out 10.java));
     ok(getfile('11_java.out'),
 	   getfile("../testfiles/11_java.out"));
     # 12
@@ -69,7 +64,8 @@ chdir 'tmp' or die;
 	}
 	else {
 		copy('../testfiles/10_java.out', '12.java');
-		`perl -I. -- starfish -o=12.out -mode=0444 12.java`;
+		#`perl -I. -- starfish -o=12.out -mode=0444 12.java`;
+		starfish_cmd(qw(-o=12.out -mode=0444 12.java));
 		my $tmp = `ls -l 12.out|sed 's/ .*//'`;
 		`chmod u+r+w 12.out`;
 		ok($tmp, getfile("../testfiles/12.out"));
@@ -79,20 +75,21 @@ chdir 'tmp' or die;
 
     # 14
     copy('../testfiles/13_java.in','14.java');
-    `perl -I. -- starfish -o=14.out -e="$slash_hack\$Star::HideMacros=1" 14.java`;
+    #`perl -I. -- starfish -o=14.out -e="$slash_hack\$Star::HideMacros=1" 14.java`;
+    starfish_cmd(qw(-o=14.out -e=$Star::HideMacros=1 14.java));
     ok(getfile('14.out'),
        getfile('../testfiles/14.out'));
 
     # 15,16
     copy('../testfiles/15.java','tmp.java');
-    `perl -I. -- starfish -o=tmp.ERR -e="$slash_hack\$Star::HideMacros=1" tmp.java>tmp1 2>&1`;
+    `$^X -I. -- starfish -o=tmp.ERR -e="$slash_hack\$Star::HideMacros=1" tmp.java>tmp1 2>&1`;
     ok($? != 0);
     okfiles('../testfiles/15.out', 'tmp1');
 
     # 17, old 16
     copy('../testfiles/16develop.SLeP','tmp.SLeP');
     copy('../testfiles/16.tex','tmp.tex');
-    `perl -I. -- starfish tmp.SLeP tmp.tex`;
+    `$^X -I. -- starfish tmp.SLeP tmp.tex`;
 	if ($^O =~ m/MSWin/) {
 	    `copy /B /Y tmp.SLeP+tmp.tex tmp1`;
 	}
@@ -103,12 +100,12 @@ chdir 'tmp' or die;
 
     # 18, old 17
     copy('../testfiles/p_t.java','tmp.java');
-    `perl -I. -- starfish -o=tmp1 tmp.java`;
+    `$^X -I. -- starfish -o=tmp1 tmp.java`;
     okfiles('../testfiles/17.out', 'tmp1');
 
     # 19, old 18
     copy('../testfiles/p_t.java', 'tmp.java');
-    `perl -I. -- starfish -e="$slash_hack\$Release=1" -o=tmp1 tmp.java`;
+    `$^X -I. -- starfish -e="$slash_hack\$Release=1" -o=tmp1 tmp.java`;
     okfiles('../testfiles/18.out', 'tmp1');
 
     # 20, old 19
@@ -117,7 +114,7 @@ chdir 'tmp' or die;
 	}
 	else {
 		copy('../testfiles/19.html', 'tmp.html');
-	    `perl -I. -- starfish -replace -o=tmp2 -mode=0644 tmp.html`;
+	    `$^X -I. -- starfish -replace -o=tmp2 -mode=0644 tmp.html`;
 	    `ls -l tmp2|sed 's/ .*//'>tmp1`;
 		okfiles('../testfiles/19.out', 'tmp1');
 	}
@@ -127,14 +124,14 @@ chdir 'tmp' or die;
 		skip('Skipped under windows...');
 	}
 	else {
-	    `perl -I. -- starfish -replace -o=tmp2 tmp.html`;
+	    `$^X -I. -- starfish -replace -o=tmp2 tmp.html`;
 	    `ls -l tmp2|sed 's/ .*//'>tmp1`;
 	    okfiles('../testfiles/20.out', 'tmp1');
 	}
 
     # 22, old 21
     copy('../testfiles/21.html','tmp2.html');
-    `perl -I. -- starfish -replace -o=tmp1 tmp2.html`;
+    `$^X -I. -- starfish -replace -o=tmp1 tmp2.html`;
     okfiles('../testfiles/21.out', 'tmp1');
 
     # 23
@@ -142,7 +139,7 @@ chdir 'tmp' or die;
 
     # 24
     copy('../testfiles/24.py','24.py');
-    `perl -I. -- starfish 24.py`;
+    `$^X -I. -- starfish 24.py`;
     okfiles('../testfiles/24.py.out', '24.py');
 
     # 26
@@ -232,15 +229,18 @@ sub testcase {
 
     copy("../testfiles/$infile", "$procfile");
     if ($replace) {
-	`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -replace -o=$replace $procfile`;
+	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -replace -o=$replace $procfile`;
+	starfish_cmd('-e=$ver="testver"', '-replace', "-o=$replace", $procfile);
 	okfiles("../testfiles/$outfile", $replace);
     }
     elsif ($out) {
-	`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -o=$out $procfile`;
+	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -o=$out $procfile`;
+	starfish_cmd('-e=$ver="testver"', "-o=$out", $procfile);
 	okfiles("../testfiles/$outfile", $out);
     }
     else {
-	`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" $procfile`;
+	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" $procfile`;
+	starfish_cmd('-e=$ver="testver"', $procfile);
 	okfiles("../testfiles/$outfile", $procfile);
     }
 }
